@@ -16,19 +16,11 @@ advanced_deployment_config_template = '''.add_configuration(
                             }})
 '''
 
-project_setup_template = '''from bigflow.build import default_project_setup
-
-PROJECT_NAME = '{project_name}'
-
-if __name__ == '__main__':
-    default_project_setup(PROJECT_NAME)
-'''
-
 beam_pipeline_template = '''import uuid
 import logging
 
 from bigflow.configuration import Config
-from bigflow.resources import find_or_create_setup_for_main_project_package, get_resource_absolute_path
+from bigflow.build.reflect import materialize_setuppy
 from apache_beam.options.pipeline_options import SetupOptions, StandardOptions, WorkerOptions, GoogleCloudOptions, \
     PipelineOptions
 
@@ -53,16 +45,14 @@ def dataflow_pipeline_options():
     google_cloud_options.staging_location = f"gs://{workflow_config['staging_location']}"
     google_cloud_options.temp_location = f"gs://{workflow_config['temp_location']}"
     google_cloud_options.region = workflow_config['region']
+    # google_cloud_options.service_account_email = 'your-service-account'
 
     options.view_as(WorkerOptions).machine_type = workflow_config['machine_type']
     options.view_as(WorkerOptions).max_num_workers = 2
     options.view_as(WorkerOptions).autoscaling_algorithm = 'THROUGHPUT_BASED'
     options.view_as(StandardOptions).runner = 'DataflowRunner'
 
-    setup_file_path = find_or_create_setup_for_main_project_package()
-    requirements_file_path = get_resource_absolute_path('requirements.txt')
-    options.view_as(SetupOptions).setup_file = str(setup_file_path)
-    options.view_as(SetupOptions).requirements_file = str(requirements_file_path)
+    options.view_as(SetupOptions).setup_file = str(materialize_setuppy().absolute())
 
     logger.info(f"Run beam pipeline with options {str(options)}")
     return options'''
